compare_json_files <- function(file1_path, file2_path) {
  require(jsonlite)
  require(dplyr)
  
  # Charger les fichiers avec gestion d'erreur
  tryCatch({
    json1 <- fromJSON(file1_path)
    json2 <- fromJSON(file2_path)
  }, error = function(e) {
    stop(paste("Erreur lors de la lecture des fichiers JSON :", e,
               "\nVérifiez que les chemins sont corrects et que les fichiers sont bien formatés"))
  })
  
  # Fonction pour analyser en détail la structure d'un objet
  analyze_structure <- function(obj, prefix = "") {
    structure <- list()
    
    if (is.data.frame(obj)) {
      # Pour les data frames, analyser chaque colonne
      for (col in names(obj)) {
        structure[[paste0(prefix, col)]] <- list(
          type = class(obj[[col]])[1],
          n_unique = length(unique(obj[[col]])),
          n_na = sum(is.na(obj[[col]])),
          example = if(length(obj[[col]]) > 0) head(obj[[col]], 1) else NA
        )
      }
    } else if (is.list(obj)) {
      # Pour les listes, analyser récursivement
      for (name in names(obj)) {
        structure[[paste0(prefix, name)]] <- analyze_structure(obj[[name]], 
                                                               paste0(prefix, name, "."))
      }
    }
    return(structure)
  }
  
  # Analyser les structures
  print("=== Analyse détaillée des différences structurelles ===")
  struct1 <- analyze_structure(json1)
  struct2 <- analyze_structure(json2)
  
  # Comparer et expliquer les différences
  print("\n1. Analyse des composants principaux :")
  main_components1 <- names(json1)
  main_components2 <- names(json2)
  
  if (!identical(main_components1, main_components2)) {
    print("Les fichiers ont des composants principaux différents :")
    print(paste("Fichier 1 contient :", paste(main_components1, collapse=", ")))
    print(paste("Fichier 2 contient :", paste(main_components2, collapse=", ")))
  }
  
  # Analyse des colonnes si ce sont des data frames
  if (is.data.frame(json1$data) && is.data.frame(json2$data)) {
    print("\n2. Analyse des colonnes :")
    cols1 <- names(json1$data)
    cols2 <- names(json2$data)
    
    # Colonnes manquantes
    missing_in_2 <- setdiff(cols1, cols2)
    missing_in_1 <- setdiff(cols2, cols1)
    
    if (length(missing_in_2) > 0) {
      print("\nColonnes présentes uniquement dans le premier fichier :")
      print(missing_in_2)
    }
    if (length(missing_in_1) > 0) {
      print("\nColonnes présentes uniquement dans le second fichier :")
      print(missing_in_1)
    }
    
    # Analyse des types de données pour les colonnes communes
    common_cols <- intersect(cols1, cols2)
    print("\n3. Différences de types de données pour les colonnes communes :")
    for (col in common_cols) {
      type1 <- class(json1$data[[col]])[1]
      type2 <- class(json2$data[[col]])[1]
      if (type1 != type2) {
        print(paste("Colonne", col, ":",
                    "\n   Fichier 1:", type1,
                    "\n   Fichier 2:", type2,
                    "\nCette différence peut causer des problèmes de traitement des données."))
      }
    }
    
    # Analyse statistique des données
    print("\n4. Analyse statistique comparative :")
    n_rows1 <- nrow(json1$data)
    n_rows2 <- nrow(json2$data)
    print(paste("Nombre d'enregistrements :",
                "\n   Fichier 1:", n_rows1,
                "\n   Fichier 2:", n_rows2))
    
    # Vérification spécifique pour les données du Brésil
    if ("source" %in% common_cols) {
      br_count1 <- sum(json1$data$source == "BR", na.rm = TRUE)
      br_count2 <- sum(json2$data$source == "BR", na.rm = TRUE)
      print(paste("\nEnregistrements du Brésil (source = 'BR') :",
                  "\n   Fichier 1:", br_count1,
                  "\n   Fichier 2:", br_count2))
    }
  }
}

compare_json_files("data/consultation_harmonized.json", "data/consultation_harmonized_original.json")
