# Malaria Lite Project Documentation 1.2

## Project Structure
The project consists of three main files:
- `notes_time_series.R`: Time series analysis
- `server.R`: Shiny server configuration and logic
- `ui.R`: Application user interface

## 1. notes_time_series.R
This script enables malaria case time series analysis.

### Main Features:
- Case incidence calculation over time
- Time series decomposition for trend and seasonality identification
- Data filtering and analysis by health center
- Temporal trend visualization

### Code Details:
```r
# Incidence calculation
consultation_date <- JSON_cons_har$consultation_date
inc <- as.data.frame(incidence(dates = consultation_date, interval = 1))
```
This section calculates daily case incidence.

```r
# Time series decomposition
inc_ts <- ts(inc$counts, frequency = 7)
inc_dec <- stl(inc_ts, s.window="periodic")
```
This part decomposes the time series to identify seasonal components.

## 2. server.R
Main Shiny server file managing application logic.

### Initial Setup:
- Loading required libraries
- Translation file import
- Utility function loading
- Geographic and consultation data initialization

### Main Modules:
1. Harmonized module (harmonized.R)
2. Harmonized localities module (harmonized_loc.R)
3. Download module (download.R)
4. Ranking module (ranking.R)
5. Information quality module (infoq.R)
6. Map module (map.R)

### Security and Terms of Use:
The server implements a modal dialog with terms of use in three languages (Portuguese, French, English), compliant with CNIL requirements.

## 3. ui.R
Shiny application user interface.

### Interface Features:
- Theme: Purple skin
- Multilingual support (EN/FR/PT)
- Dashboard structure with sidebar
- Google Analytics integration

### Main Components:
```r
dashboardPage(
  dashboardHeader(...),  # Header with title
  dashboardSidebar(...), # Sidebar with menu and language selection
  dashboardBody(...)     # Main body with dynamic content
)
```

## JSON Data Structures

### Consultation Data Format (`consultation_harmonized.json`)
```json
{
  "data": [
    {
      "id_consultation": "string",      // Unique consultation ID
      "source": "string",               // "BR" or "FR-GF"
      "consultation_date": "DD/MM/YYYY", // Date in French format
      "id_center": "string",            // Health center ID
      "residence_place": "string",      // Residence place ID
      "infection_place": "string",      // Presumed infection place ID
      "patient_age": "number",          // Patient age (0-100)
      "patient_sex": "string",          // "Male", "Female" or "Desconhecido"
      "diagnosis_result": "string",     // Result code (1-11)
      "active_diagnosis": "boolean",    // Active or passive diagnosis
      "new_attack": "boolean"           // New attack or relapse
    }
  ]
}
```

## Time Series Decomposition Algorithms

### 1. STL Decomposition (Seasonal-Trend using Loess)

```r
# Main decomposition function
decompose <- function(x) {
  # Data preparation
  date1 <- min(x)
  date2 <- max(x)
  
  # Daily incidence calculation
  inc <- as.data.frame(incidence(dates = x, interval = 1)) 
  
  # Missing dates completion
  full <- data.frame(dates = seq(date1, date2, by = "day"))
  inc <- dplyr::right_join(inc, full, by = "dates")
  inc[is.na(inc)] <- 0
  
  # Time series creation with annual frequency
  inc_ts <- ts(inc$counts, frequency = 365)
  
  # STL decomposition
  inc_dec <- stl(inc_ts, s.window="periodic")
  
  return(df_dec)
}
```

Decomposition Components:
1. **Trend**: Long-term evolution
2. **Seasonality**: Annual cyclic patterns
3. **Remainder**: Unexplained variations

## Implementation Notes

### Geographic Data Management:
- Use of shapefiles for spatial data
- Support for Brazil (BR) and French Guiana (GF) coordinates
- Unique identifier management (id_sivep, id_cdps)

### Data Security:
- Anonymized data as per CNIL requirements
- Authorized automated processing (Decision N°2019-025)
- Commercial use restrictions

### Performance:
- Optimized data loading
- Efficient use of st_read for shape files
- Effective data joining management

## Maintenance Instructions

To update the application:
1. Update JSON files in "data/" folder
2. Check last update dates in "data/dates_recup_donnees_syst_surveillance.txt"
3. Validate translations in "locale/translation.bin"
4. Test filtering and visualization functionalities

## Shiny Modules (modules/ folder)

### Harmonized Analysis Modules

1. `harmonized.R`
- Analysis of harmonized data between BR and FR-GF
- Temporal visualizations (incidence, age, sex, plasmodium)
- Dynamic filters (dates, cases, diagnosis, age, sex)
- Reactive statistics calculations

2. `harmonized_loc.R`
- Geographic analysis of harmonized data
- Location-based visualization
- Multi-country support (BR/FR-GF)
- Configurable temporal aggregation

### Map Module

`map.R`
- Interactive mapping interface
- OpenStreetMap integration
- Case visualization by area
- GBIF data support for Anopheles
- WMS layers for risk models

Key Module Features:
1. Reactivity: Extensive use of Shiny reactive functions
2. Modularity: Clear separation of responsibilities
3. Multilingual: Integrated support for 3 languages
4. Performance: Calculation and rendering optimization
5. Extensibility: Architecture allowing new module addition