# Documentação do Projeto Malaria Lite 1.2

## Estrutura do Projeto
O projeto é composto por três arquivos principais:
- `notes_time_series.R`: Análise de séries temporais
- `server.R`: Configuração e lógica do servidor Shiny
- `ui.R`: Interface do usuário da aplicação

## 1. notes_time_series.R
Este script permite a análise de séries temporais dos casos de malária.

### Funcionalidades Principais:
- Cálculo da incidência de casos ao longo do tempo
- Decomposição de séries temporais para identificação de tendências e sazonalidade
- Filtragem e análise de dados por centro de saúde
- Visualização de tendências temporais

### Detalhes do Código:
```r
# Cálculo da incidência
consultation_date <- JSON_cons_har$consultation_date
inc <- as.data.frame(incidence(dates = consultation_date, interval = 1))
```
Esta seção calcula a incidência diária de casos.

```r
# Decomposição de séries temporais
inc_ts <- ts(inc$counts, frequency = 7)
inc_dec <- stl(inc_ts, s.window="periodic")
```
Esta parte decompõe a série temporal para identificar componentes sazonais.

## 2. server.R
Arquivo principal do servidor Shiny que gerencia a lógica da aplicação.

### Configuração Inicial:
- Carregamento das bibliotecas necessárias
- Importação dos arquivos de tradução
- Carregamento das funções utilitárias
- Inicialização dos dados geográficos e de consultas

### Módulos Principais:
1. Módulo harmonizado (harmonized.R)
2. Módulo de localidades harmonizadas (harmonized_loc.R)
3. Módulo de download (download.R)
4. Módulo de classificação (ranking.R)
5. Módulo de qualidade da informação (infoq.R)
6. Módulo de mapa (map.R)

### Segurança e Termos de Uso:
O servidor implementa uma caixa de diálogo modal com termos de uso em três idiomas (português, francês, inglês), em conformidade com os requisitos da CNIL.

## 3. ui.R
Interface do usuário da aplicação Shiny.

### Características da Interface:
- Tema: Skin roxa
- Suporte multilíngue (EN/FR/PT)
- Estrutura de painel com barra lateral
- Integração com Google Analytics

### Componentes Principais:
```r
dashboardPage(
  dashboardHeader(...),  # Cabeçalho com título
  dashboardSidebar(...), # Barra lateral com menu e seleção de idioma
  dashboardBody(...)     # Corpo principal com conteúdo dinâmico
)
```

## Estruturas de Dados JSON

### Formato dos Dados de Consulta (`consultation_harmonized.json`)
```json
{
  "data": [
    {
      "id_consultation": "string",      // ID único da consulta
      "source": "string",               // "BR" ou "FR-GF"
      "consultation_date": "DD/MM/YYYY", // Data no formato francês
      "id_center": "string",            // ID do centro de saúde
      "residence_place": "string",      // ID do local de residência
      "infection_place": "string",      // ID do local presumido de infecção
      "patient_age": "number",          // Idade do paciente (0-100)
      "patient_sex": "string",          // "Male", "Female" ou "Desconhecido"
      "diagnosis_result": "string",     // Código do resultado (1-11)
      "active_diagnosis": "boolean",    // Diagnóstico ativo ou passivo
      "new_attack": "boolean"           // Novo ataque ou recaída
    }
  ]
}
```

## Algoritmos de Decomposição Temporal

### 1. Decomposição STL (Seasonal-Trend using Loess)

```r
# Função principal de decomposição
decompose <- function(x) {
  # Preparação dos dados
  date1 <- min(x)
  date2 <- max(x)
  
  # Cálculo da incidência diária
  inc <- as.data.frame(incidence(dates = x, interval = 1)) 
  
  # Preenchimento de datas faltantes
  full <- data.frame(dates = seq(date1, date2, by = "day"))
  inc <- dplyr::right_join(inc, full, by = "dates")
  inc[is.na(inc)] <- 0
  
  # Criação da série temporal com frequência anual
  inc_ts <- ts(inc$counts, frequency = 365)
  
  # Decomposição STL
  inc_dec <- stl(inc_ts, s.window="periodic")
  
  return(df_dec)
}
```

Componentes da Decomposição:
1. **Tendência**: Evolução a longo prazo
2. **Sazonalidade**: Padrões cíclicos anuais
3. **Resíduos**: Variações não explicadas

## Notas de Implementação

### Gestão de Dados Geográficos:
- Uso de shapefiles para dados espaciais
- Suporte para coordenadas do Brasil (BR) e Guiana Francesa (GF)
- Gestão de identificadores únicos (id_sivep, id_cdps)

### Segurança dos Dados:
- Dados anonimizados conforme requisitos CNIL
- Processamento automatizado autorizado (Decisão N°2019-025)
- Restrições de uso comercial

### Desempenho:
- Carregamento otimizado de dados
- Uso eficiente de st_read para arquivos shape
- Gestão eficaz de junções de dados

## Instruções de Manutenção

Para atualizar a aplicação:
1. Atualizar arquivos JSON na pasta "data/"
2. Verificar datas de última atualização em "data/dates_recup_donnees_syst_surveillance.txt"
3. Validar traduções em "locale/translation.bin"
4. Testar funcionalidades de filtragem e visualização

## Módulos Shiny (pasta modules/)

### Módulos de Análise Harmonizada

1. `harmonized.R`
- Análise de dados harmonizados entre BR e FR-GF
- Visualizações temporais (incidência, idade, sexo, plasmodium)
- Filtros dinâmicos (datas, casos, diagnóstico, idade, sexo)
- Cálculos estatísticos reativos

2. `harmonized_loc.R`
- Análise geográfica de dados harmonizados
- Visualização baseada em localização
- Suporte multi-país (BR/FR-GF)
- Agregação temporal configurável

### Módulo de Mapa

`map.R`
- Interface de mapeamento interativa
- Integração com OpenStreetMap
- Visualização de casos por área
- Suporte a dados GBIF para Anopheles
- Camadas WMS para modelos de risco

Características Principais dos Módulos:
1. Reatividade: Uso extensivo de funções reativas Shiny
2. Modularidade: Separação clara de responsabilidades
3. Multilíngue: Suporte integrado para 3 idiomas
4. Desempenho: Otimização de cálculos e renderização
5. Extensibilidade: Arquitetura permitindo adição de novos módulos