# Packages
library(jsonlite)
library(shiny)
library(shinydashboard)
library(incidence)
library(plotly)
library(tidyr)
library(reshape2)
library(lubridate)
library(chron)
library(dplyr)
library(formattable)
library(DT)
library(leaflet)
library(readr)
library(stringr)
#library(rgdal)
library(sf)
library(osmdata)

t <- Sys.time()

# Load translated strings, parsed as a double list
load("locale/translation.bin") 

str_glue("Load translations done : {Sys.time() - t} sec.") %>% print()

# Load ingest functions
source("functions/consultation_har_ingest.R")
source("functions/area_har_ingest.R")
source("functions/healthcenter_har_ingest.R")

# Load filter functions
source("functions/consultation_har_filter.R")

# Load other functions
source("functions/calendarHeat.R")
source("functions/addLegendCustom.R")
#source("functions/decompose.R")

# Find Last Download Date
source("functions/last_update.R")

str_glue("Load functions done : {Sys.time() - t} sec.") %>% print()

# Load JSON files
JSON_cons_har <- consultation_har_ingest("data/", "consultation_harmonized.json")
# JSON_healthcenter_har <- read_csv(
#   file = "data/JSON_healthcenter_har.csv", col_types="-cnccn")
JSON_healthcenter_har <- read.csv(file = "data/JSON_healthcenter_har.csv", header=TRUE)


# Load shapefile and "create" JSON_area_har
# unique_loc.shp <- readOGR("data/shp", "unique_Spatial_referential_2019_07_01", encoding = "UTF-8")
# unique_loc <- unique_loc.shp@data %>%
#   select(country, name, id_sivep, id_cdps, geocoded) %>%
#   cbind(coordinates(unique_loc.shp))

unique_loc.shp <- st_read(
  dsn="data/shp", layer = "unique_Spatial_referential_2019_07_01",
  options = "ENCODING=UTF-8")
coords_loc <- st_coordinates(unique_loc.shp)
unique_loc <- unique_loc.shp %>%
  select(country, name, id_sivep, id_cdps, geocoded) %>%
  mutate(coords.x1 = coords_loc[,1], coords.x2 = coords_loc[,2]) %>%
  st_drop_geometry()
unique_loc_br <- unique_loc %>% 
  filter(country == "BR") %>%
  filter(!is.na(id_sivep))
unique_loc_gf <- unique_loc %>% 
  filter(country == "GF") %>%
  filter(!is.na(id_cdps))
unique_loc_both <- unique_loc_br %>%
  filter(!is.na(id_sivep) & !is.na(id_cdps)) %>%
  mutate(id_sivep = id_cdps) %>%
  mutate(country = "GF") %>%
  mutate(coords.x1 = coords.x1 + 0.001) %>%
  mutate(coords.x2 = coords.x2 + 0.001) %>%
  mutate(name = paste(name, "(FR-GF)"))
unique_loc_br <- unique_loc_br %>%
  mutate(name = as.character(name)) %>%
  mutate(name = ifelse(!is.na(id_sivep) & !is.na(id_cdps), paste(name, "(BR)"), name))
unique_loc <- rbind(unique_loc_br, unique_loc_gf) %>% 
  rbind(unique_loc_both) %>%
  select(-id_cdps) %>%
  rename(source = country) %>%
  rename(x_coordinate = coords.x1) %>%
  rename(y_coordinate = coords.x2) %>%
  rename(id = id_sivep) %>%
  mutate(source = ifelse(source == "GF", "FR-GF", "BR"))
JSON_area_har <- unique_loc
rm(unique_loc, unique_loc_br, unique_loc_gf, unique_loc_both, unique_loc.shp)

#coords <- read.csv2("data/map.csv")
coords <- JSON_area_har %>%
  filter(geocoded == TRUE) %>%
  select(id, name, x_coordinate, y_coordinate)
#filter(x_coordinate <= -51)

str_glue("Process SHP + JSON done : {Sys.time() - t} sec.") %>% print()

dates_recup_donnees <- last_update("data/dates_recup_donnees_syst_surveillance.txt")
# text_recup_donnees <- paste0(
#   "Date of last data retrieval", 
#   "\nfrom SIVEP-Malária (BR) : ", dates_recup_donnees[["date_recup_donnees_SIVEP"]], 
#   "\nfrom CDPS database (FR-GF) : ", dates_recup_donnees[["date_recup_donnees_CDPS"]])
text_recup_donnees_BR <-dates_recup_donnees[["date_recup_donnees_SIVEP"]]
text_recup_donnees_GF <-dates_recup_donnees[["date_recup_donnees_CDPS"]]


# Initate server side modules
shinyServer(function(input, output, session) {
  
  # Function to translate key 
  source("functions/translate.R", local = TRUE)
  
  # Tab harmonized
  source("modules/harmonized.R", local = TRUE)
  
  # Tab harmonized localities
  source("modules/harmonized_loc.R", local = TRUE)
  
  # Tab trends (not ready)
  # source("modules/trends.R", local = TRUE)
  
  # Tab download
  source("modules/download.R", local = TRUE)
  
  # Tab ranking
  source("modules/ranking.R", local = TRUE)
  
  # Tab information quality
  source("modules/infoq.R", local = TRUE)
  
  # Tab Brazil
  # ToDo
  
  # Tab French Guiana
  # ToDo
  
  # Tab map
  source("modules/map.R", local = TRUE)
  
  # Dynamic server UI
  source("modules/server_ui.R", local = TRUE)
  
  # Modal
  showModal(modalDialog(
    #title = "Term of use",
    size = "l",
    tags$h3("Informações Gerais e Condições de Utilização"),
    tags$p("Você está acessando informações epidemiológicas coletadas de maneira passiva pelos Centros de Prevenção e Cuidado Não Localizados (CDPS, Centro Hospitalar Andrée Rosemon em Caiena) da Guiana Francesa e de centros de notificação no Brasil, de pacientes com malária que foram consultados, residem ou relataram um local suspeito de infeção em um dos seguintes municípios: Saint-Georges-de-l'Oyapock, Ouanary, Camopi (Guiana Francesa), ou Oiapoque (Brasil)."),
    tags$p("Esta informação é apresentada de forma anonimizada e agregada, resultado de um processamento automático autorizado pelo Commission Nationale Informatique et Liberté (CNIL) (Deliberação No. 2019-025 do dia 28 de fevereiro de 2019, pedido de autorização No. 2135363)"),
    tags$b("O uso da informação disponível através deste sistema não deve, sob qualquer circunstância, ser usado para fins comerciais."),
    tags$p("Qualquer publicação de dados e/ou resultados obtidos através do uso deste sistema deve mencionar explicitamente o endereço na Internet do sistema e a data de último acesso ao sistema."),
    tags$h3("Informations Générales et Conditions d'Utilisation"),
    tags$p("Vous êtes sur le point d’accéder à des informations épidémiologiques recueillies de manière passive dans les Centres Délocalisés de Prévention et de Soin (CDPS, Centre Hospitalier Andrée Rosemon de Cayenne) de Guyane française ainsi que dans les centres de notification du Brésil, auprès de patients atteints de paludisme et ayant consulté, résidant, ou ayant déclaré un lieu présumé d'infection dans l’une des communes suivantes : Saint-Georges-de-l’Oyapock, Ouanary, Camopi (Guyane française), ou Oiapoque (Brésil)."),
    tags$p("Ces informations sont présentées anonymisées et agrégées, et résultent d’un traitement automatisé autorisé par la Commission Nationale Informatique et Liberté (CNIL) (Délibération N°2019-025 du 28 février 2019, demande d'autorisation N°2135363)."),
    tags$b("L’utilisation des informations disponibles via ce système ne doit en aucun cas être à but commercial."),
    tags$p("Toute publication de données et/ou de résultats obtenus via l’utilisation de ce système devra mentionner explicitement l'adresse internet du système et la date du dernier accès au système."),
    tags$h3("General Information and Terms and conditions of use"),
    tags$p("You are about to access epidemiological information collected in a passive mode from Delocalized Prevention and Care Centres (CDPS, Andrée Rosemon Hospital Centre in Cayenne) of French Guiana and notification centres in Brazil, from patients with malaria who have consulted, reside in, or have reported a suspected place of infection in one of the following municipalities: Saint-Georges-de-l'Oyapock, Ouanary, Camopi (French Guiana), or Oiapoque (Brazil)."),
    tags$p("These information are presented anonymized and aggregated, and result from an automated processing authorized by the Commission Nationale Informatique et Liberté (CNIL) (Deliberation no. 2019-025 of 28 February 2019, request for authorisation No. 2135363)."),
    tags$b("The use of the information available through this system must under no circumstances be for commercial purposes."),
    tags$p("Any publication of data and/or results obtained through the use of this system must explicitly mention the Internet address of the system and the date of last access to the system."),
    easyClose = FALSE,
    footer = tagList(
      modalButton("Eu li e aceito as condições de utilização | J’ai lu et j’accepte les conditions d’utilisation |\n I have read and accept the terms of use")
    )
    
  ))
})

